/*--------------------------------------------------------------------------*\
 |                                                                          |
 |  Copyright (C) 2019                                                      |
 |                                                                          |
 |      Enrico Bertolazzi (1) & Andreas Huber (2)                           |
 |      (1) Dipartimento di Ingegneria Industriale                          |
 |          Universita` degli Studi di Trento                               |
 |          email: enrico.bertolazzi@unitn.it                               |
 |      (2) Fakultät für Luft- und Raumfahrttechnik                         |
 |          Universität der Bundeswehr München                              |
 |          email: info@ocpbasic.com                                        |
\*--------------------------------------------------------------------------*/

/*
 * Commercial license:
 *
 * To get more information about the commercial licence and the commercial use of OCPbasic and IPbasic please contact
 *      info@ocpbasic.com
 *
 * Open source license: (LGPLv3)
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 3.0 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

/**
 * @file IPbasic_Myfunction.h
 * Header definition of the class MyFunction.
 * You can find further informationen in the documentation of the class MyFunction.
 *
 * @author A. Huber
 * @since 14.08.2017
 */

#ifndef MYFUNCTION_H
#define MYFUNCTION_H

#include "../IPbasic.h"
#include <string>

namespace IPbasic
{

    class MyFunction
    {

        typedef void (*MyFunctionPtr)(string_type const &);

        /// Is the external function set?
        bool externalFunctionAssigned;

        /// Pointer on the external function:
        MyFunctionPtr externalFunction;

        /**
         * \brief DefaultFunction:
         *        Default function.
         *
         * \param[in] String    Given string.
         *
        \*/
        static void DefaultFunction(string_type const & String);

        MyFunction(MyFunction const &);

      public:
        /**
         * \brief MyFunction:
         *        Default constructor of the class MyFunction.
        \*/
        MyFunction();

        /**
         * \brief MyFunction:
         *        constructor of the class MyFunction, with a given function.
        \*/
        MyFunction(MyFunctionPtr);

        /**
         * \brief ~MyFunction:
         *        Virtual destructor of the class MyFunction.
        \*/
        virtual ~MyFunction();

        MyFunction const & operator=(MyFunction const & rhs)
        {
            this->externalFunctionAssigned = rhs.externalFunctionAssigned;
            this->externalFunction         = rhs.externalFunction;
            return *this;
        }

        /**
         * \brief setExternalFunction:
         *        Sets the external function.
        \*/
        void setExternalFunction(MyFunctionPtr);

        /**
         * \brief runExternalFunction:
         *        Runs the external function.
         *
         * \param[in] String    Given string.
         *
        \*/
        void runExternalFunction(string_type const & String);
    };

} // namespace IPbasic

#endif // MYFUNCTION_H
