/*--------------------------------------------------------------------------*\
 |                                                                          |
 |  Copyright (C) 2019                                                      |
 |                                                                          |
 |      Enrico Bertolazzi (1) & Andreas Huber (2)                           |
 |      (1) Dipartimento di Ingegneria Industriale                          |
 |          Universita` degli Studi di Trento                               |
 |          email: enrico.bertolazzi@unitn.it                               |
 |      (2) Fakultät für Luft- und Raumfahrttechnik                         |
 |          Universität der Bundeswehr München                              |
 |          email: info@ocpbasic.com                                        |
\*--------------------------------------------------------------------------*/

/*
 * Commercial license:
 *
 * To get more information about the commercial licence and the commercial use of OCPbasic and IPbasic please contact
 *      info@ocpbasic.com
 *
 * Open source license: (LGPLv3)
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 3.0 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

/**
 * @file mycolorsdef.h
 * Header definitionens of different colors in a Terminal.
 *
 * @author A. Huber
 * @since 07.03.2017
 */

#ifndef MYCOLORDEF
#define MYCOLORDEF

#include "../IPbasic.h"

namespace IPbasic
{

    class TermColor
    {
#if defined(IPBASIC_OS_LINUX) || defined(IPBASIC_OS_OSX)
        static ostream_type * pStream;
#elif defined(IPBASIC_OS_WINDOWS)
        static HANDLE hConsole;
#endif

      public:
#if defined(IPBASIC_OS_LINUX) || defined(IPBASIC_OS_OSX)

        /// Default color of the Terminal.
        static void set_COLOR_DEFAULT()
        {
            (*pStream) << "\033[0m";
        }

        /// Red color in the Terminal.
        static void set_COLOR_RED()
        {
            (*pStream) << "\033[1;31m";
        }

        /// Green color in the Terminal.
        static void set_COLOR_GREEN()
        {
            (*pStream) << "\033[1;32m";
        }

        /// Yellow color in the Terminal.
        static void set_COLOR_YELLOW()
        {
            (*pStream) << "\033[1;33m";
        }

        /// Darkblue color in the Terminal.
        static void set_COLOR_DARK_BLUE()
        {
            (*pStream) << "\033[1;34m";
        }

        /// Purple color in the Terminal.
        static void set_COLOR_PURPLE()
        {
            (*pStream) << "\033[1;35m";
        }

        /// Lightblue color in the Terminal.
        static void set_COLOR_LIGHT_BLUE()
        {
            (*pStream) << "\033[1;36m";
        }

#elif defined(IPBASIC_OS_WINDOWS)

        /// Default color of the Terminal.
        static void set_COLOR_DEFAULT()
        {
            SetConsoleTextAttribute(hConsole, WORD(15));
        }

        /// Red color in the Terminal.
        static void set_COLOR_RED()
        {
            SetConsoleTextAttribute(hConsole, WORD(12));
        }

        /// Green color in the Terminal.
        static void set_COLOR_GREEN()
        {
            SetConsoleTextAttribute(hConsole, WORD(10));
        }

        /// Yellow color in the Terminal.
        static void set_COLOR_YELLOW()
        {
            SetConsoleTextAttribute(hConsole, WORD(14));
        }

        /// Darkblue color in the Terminal.
        static void set_COLOR_DARK_BLUE()
        {
            SetConsoleTextAttribute(hConsole, WORD(9));
        }

        /// Purple color in the Terminal.
        static void set_COLOR_PURPLE()
        {
            SetConsoleTextAttribute(hConsole, WORD(13));
        }

        /// Lightblue color in the Terminal.
        static void set_COLOR_LIGHT_BLUE()
        {
            SetConsoleTextAttribute(hConsole, WORD(11));
        }

#else

        /// Default color of the Terminal.
        static void set_COLOR_DEFAULT()
        {
        }

        /// Red color in the Terminal.
        static void set_COLOR_RED()
        {
        }

        /// Green color in the Terminal.
        static void set_COLOR_GREEN()
        {
        }

        /// Yellow color in the Terminal.
        static void set_COLOR_YELLOW()
        {
        }

        /// Darkblue color in the Terminal.
        static void set_COLOR_DARK_BLUE()
        {
        }

        /// Purple color in the Terminal.
        static void set_COLOR_PURPLE()
        {
        }

        /// Lightblue color in the Terminal.
        static void set_COLOR_LIGHT_BLUE()
        {
        }

#endif

        template <typename real>
        static void set3color(real a, real abig, real amed)
        {
            if (a >= abig)
                set_COLOR_RED();
            else if (a > amed)
                set_COLOR_YELLOW();
            else
                set_COLOR_GREEN();
        }

        template <typename real>
        static void set3colorR(real a, real abig, real amed)
        {
            if (a >= abig)
                set_COLOR_GREEN();
            else if (a > amed)
                set_COLOR_YELLOW();
            else
                set_COLOR_RED();
        }
    };

} // namespace IPbasic

#endif // MYCOLORDEF
