/*--------------------------------------------------------------------------*\
 |                                                                          |
 |  Copyright (C) 2019                                                      |
 |                                                                          |
 |      Enrico Bertolazzi (1) & Andreas Huber (2)                           |
 |      (1) Dipartimento di Ingegneria Industriale                          |
 |          Universita` degli Studi di Trento                               |
 |          email: enrico.bertolazzi@unitn.it                               |
 |      (2) Fakultät für Luft- und Raumfahrttechnik                         |
 |          Universität der Bundeswehr München                              |
 |          email: info@ocpbasic.com                                        |
\*--------------------------------------------------------------------------*/

/*
 * Commercial license:
 *
 * To get more information about the commercial licence and the commercial use of OCPbasic and IPbasic please contact
 *      info@ocpbasic.com
 *
 * Open source license: (LGPLv3)
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 3.0 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

/**
 * @file IPbasic_IPtimings.h
 * Header definitions of the class IPtimings.
 *
 * @author A. Huber
 * @since 20.05.2019
 */

#ifndef IPBASIC_TIMINGS_H
#define IPBASIC_TIMINGS_H

#include "IPbasic.h"

namespace IPbasic
{

    template <typename real>
    class IPtimings
    {
      public:
        /**
         * \brief IPtimings:
         *        Constructor of the class IPtimings.
         */
        IPtimings();

        /**
         * \brief ~IPtimings:
         *        Virtual Destructor of the class IPtimings.
         */
        virtual ~IPtimings();

        /**
         * \brief resetTimings:
         *        Reset the timings.
         */
        virtual void resetTimings();

        /**
         * \brief printTimeings:
         *        Print the timings.
         */
        virtual void printTimeings(ostream_type &);

        /// Time to optimize the problem with IPbasic.
        real TimeOptimize;
        /// Time for factorizing the linear system.
        real TimeFactorize;
        /// Time for solving the linear system.
        real TimeSolve;
        /// Time for data update.
        real TimeDataUpdate;
        /// Time for the update of the hessian.
        real TimeHessianUpdate;
        /// Time for the update of the jacobian.
        real TimeJacobianUpdate;
        /// Time to set up the interior-point system.
        real TimeSetupIPSystem;
        /// Time to evaluate the linesearch.
        real TimeLineSearch;
    };

} // namespace IPbasic

#endif // IPBASIC_IPTIMINGS_H
