/*--------------------------------------------------------------------------*\
 |                                                                          |
 |  Copyright (C) 2019                                                      |
 |                                                                          |
 |      Enrico Bertolazzi (1) & Andreas Huber (2)                           |
 |      (1) Dipartimento di Ingegneria Industriale                          |
 |          Universita` degli Studi di Trento                               |
 |          email: enrico.bertolazzi@unitn.it                               |
 |      (2) Fakultät für Luft- und Raumfahrttechnik                         |
 |          Universität der Bundeswehr München                              |
 |          email: info@ocpbasic.com                                        |
\*--------------------------------------------------------------------------*/

/*
 * Commercial license:
 *
 * To get more information about the commercial licence and the commercial use of OCPbasic and IPbasic please contact
 *      info@ocpbasic.com
 *
 * Open source license: (LGPLv3)
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 3.0 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

/**
 * @file IPbasic_LineSearch.h
 * Header definitions of the class LineSearch.
 *
 * @author A. Huber
 * @since 08.02.2019
\*/

#ifndef IPBASIC_LINESEARCH_H
#define IPBASIC_LINESEARCH_H

#include "../IPbasic.h"
#include "../IPbasic_Data.h"

namespace IPbasic
{

    template <typename real>
    class LineSearch
    {
      public:
        /**
         * \brief LineSearch:
         *        Constructor of the class LineSearch.
        \*/
        LineSearch();

        /**
         * \brief ~LineSearch:
         *        Virtual destructor of the class LineSearch.
        \*/
        virtual ~LineSearch();

        /*\
        :|:             _    _ _                      _
        :|:   _ __ _  _| |__| (_)__   _ __  ___ _ __ | |__  ___ _ _ ___
        :|:  | '_ \ || | '_ \ | / _| | '  \/ -_) '  \| '_ \/ -_) '_(_-<
        :|:  | .__/\_,_|_.__/_|_\__| |_|_|_\___|_|_|_|_.__/\___|_| /__/
        :|:  |_|
        \*/

        /**
         * \brief getStepsize:
         *        Calculate a stepsize for the current search direction.
         *
         * \param[in] IPD           Data of the interior-point-method.
         * \param[in] alpha_max     Maximal value of the stepsize.
         *
         * @return A stepsize \f$\alpha \in (0, \alpha_{\mathrm{max}}]\f$.
         *         (Default retruns \f$\alpha_{\mathrm{max}}\f$)
         *
        \*/
        virtual real getStepsize(IPdata<real> * IPD, real alpha_max);
    };

} // namespace IPbasic

#endif // IPBASIC_LINESEARCH_H
