/*--------------------------------------------------------------------------*\
 |                                                                          |
 |  Copyright (C) 2019                                                      |
 |                                                                          |
 |      Enrico Bertolazzi (1) & Andreas Huber (2)                           |
 |      (1) Dipartimento di Ingegneria Industriale                          |
 |          Universita` degli Studi di Trento                               |
 |          email: enrico.bertolazzi@unitn.it                               |
 |      (2) Fakultät für Luft- und Raumfahrttechnik                         |
 |          Universität der Bundeswehr München                              |
 |          email: info@ocpbasic.com                                        |
\*--------------------------------------------------------------------------*/

/*
 * Commercial license:
 *
 * To get more information about the commercial licence and the commercial use of OCPbasic and IPbasic please contact
 *      info@ocpbasic.com
 *
 * Open source license: (LGPLv3)
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 3.0 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

/*!
 * \file IPbasic_LineSearchFunction.h
 * Header definitions of the class LineSearchFunction.
 *
 * \author A. Huber
 * \since 08.02.2019
 */

#ifndef IPBASIC_LINESEARCHFUNCTION_H
#define IPBASIC_LINESEARCHFUNCTION_H

#include "../IPbasic.h"
#include "../IPbasic_Data.h"

namespace IPbasic
{

    template <typename real>
    class LineSearchFunction
    {
      protected:
        /*!
         * \brief LineSearchFunction:
         *        Constructor of the class LineSearchFunction.
         */
        LineSearchFunction();

      public:
        /*!
         * \brief ~LineSearchFunction:
         *        Virtual destructor of the class LineSearchFunction.
         */
        virtual ~LineSearchFunction();

        /*\
        :|:             _    _ _                      _
        :|:   _ __ _  _| |__| (_)__   _ __  ___ _ __ | |__  ___ _ _ ___
        :|:  | '_ \ || | '_ \ | / _| | '  \/ -_) '  \| '_ \/ -_) '_(_-<
        :|:  | .__/\_,_|_.__/_|_\__| |_|_|_\___|_|_|_|_.__/\___|_| /__/
        :|:  |_|
        \*/

        /*!
         * \brief getF:
         *        Get the value of the line-search-function.
         *
         * \param[in] IPD   Data of the interior-point-method.
         * \param[in] alpha Stepsize.
         *
         * \return The value of the line-search-function.
         *
         */
        virtual real getF(IPdata<real> * IPD, real alpha) IPBASIC_PURE_VIRTUAL;

        /*!
         * \brief getDF:
         *        Get the derivative of the line-search-function.
         *
         * \param[in] IPD   Data of the interior-point-method.
         *
         * \return The derivative of the line-search-function.
         *
         */
        virtual real getDF(IPdata<real> * IPD) IPBASIC_PURE_VIRTUAL;
    };

} // namespace IPbasic

#endif // IPBASIC_LINESEARCHFUNCTION_H
